SecureDeviceCheckPlatform class abstract

The interface that implementations of secure_device_check must implement.

Inheritance
  • Object
  • PlatformInterface
  • SecureDeviceCheckPlatform
Implementers

Constructors

SecureDeviceCheckPlatform()
Constructs a SecureDeviceCheckPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
onScreenshotDetected Stream<void>
A stream that fires every time a system screenshot is detected natively.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

disableScreenProtection() Future<void>
Disables screen protection, restoring normal behavior.
enableScreenProtection() Future<void>
Enables screen protection (blocks screenshots and screen recording).
isDeveloperOptionsEnabled() Future<Map<String, bool>>
Returns a map with developer options status.
isDeviceCompromised() Future<bool>
Returns true if the device is rooted (Android) or jailbroken (iOS).
isEmulator() Future<bool>
Returns true if the app is running on an emulator or simulator.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance SecureDeviceCheckPlatform
The default instance of SecureDeviceCheckPlatform to use.
getter/setter pair