MethodChannelSecureDeviceCheck class
An implementation of SecureDeviceCheckPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- SecureDeviceCheckPlatform
- MethodChannelSecureDeviceCheck
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
-
onScreenshotDetected
→ Stream<
void> -
A stream that fires every time a system screenshot is detected natively.
no setteroverride
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableScreenProtection(
) → Future< void> -
Disables screen protection, restoring normal behavior.
override
-
enableScreenProtection(
) → Future< void> -
Enables screen protection (blocks screenshots and screen recording).
override
-
isDeveloperOptionsEnabled(
) → Future< Map< String, bool> > -
Returns a map with developer options status.
override
-
isDeviceCompromised(
) → Future< bool> -
Returns
trueif the device is rooted (Android) or jailbroken (iOS).override -
isEmulator(
) → Future< bool> -
Returns
trueif the app is running on an emulator or simulator.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited